﻿using Android.App;
using Android.Widget;
using Android.OS;

namespace Demo
{
    [Activity(Label = "Enhance Xamarin Demo", MainLauncher = true, Icon = "@mipmap/icon", Theme = "@android:style/Theme.Holo.Light", ScreenOrientation = Android.Content.PM.ScreenOrientation.Portrait)]
    public class MainActivity : Activity
    {
        protected bool isBannerAdShown = false;
        protected bool hasLocalNotificationPermission = false;
        protected string productName = "Enhance_SKU_One";

        protected override void OnCreate(Bundle savedInstanceState)
        {
            base.OnCreate(savedInstanceState);

            // Set our view from the "main" layout resource
            SetContentView(Resource.Layout.Main);

            // Get buttons
            Button interstitialButton = FindViewById<Button>(Resource.Id.showInterstitialButton);
            Button rewardedButton = FindViewById<Button>(Resource.Id.showRewardedAdButton);
            Button bannerButton = FindViewById<Button>(Resource.Id.toggleBannerButton);
            Button offerwallButton = FindViewById<Button>(Resource.Id.showOfferwallButton);
            Button specialOfferButton = FindViewById<Button>(Resource.Id.showSpecialOfferButton);
            Button eventButton = FindViewById<Button>(Resource.Id.logEventButton);
            Button enableNotificationButton = FindViewById<Button>(Resource.Id.enableLocalNotificationButton);
            Button disableNotificationButton = FindViewById<Button>(Resource.Id.disableLocalNotificationButton);
            Button purchaseButton = FindViewById<Button>(Resource.Id.purchaseButton);
            Button consumeButton = FindViewById<Button>(Resource.Id.consumeButton);
            Button gdprOptInButton = FindViewById<Button>(Resource.Id.gdprOptInButton);
            Button gdprOptOutButton = FindViewById<Button>(Resource.Id.gdprOptOutButton);
            Button gdprDialogsButton = FindViewById<Button>(Resource.Id.gdprDialogsButton);

            // Assign callbacks to buttons
            interstitialButton.Click += delegate { OnShowInterstitialAd(); };
            rewardedButton.Click += delegate { OnShowRewardedAd(); };
            bannerButton.Click += delegate { OnToggleBanner(); };
            offerwallButton.Click += delegate { OnShowOfferwall(); };
            specialOfferButton.Click += delegate { OnShowSpecialOffer(); };
            eventButton.Click += delegate { OnLogEvent(); };
            enableNotificationButton.Click += delegate { OnEnableLocalNotification(); };
            disableNotificationButton.Click += delegate { OnDisableLocalNotification(); };
            purchaseButton.Click += delegate { OnAttemptPurchase(); };
            consumeButton.Click += delegate { OnAttemptConsume(); };
            gdprOptInButton.Click += delegate { OnGDPROptIn(); };
            gdprOptOutButton.Click += delegate { OnGDPROptOut(); };
            gdprDialogsButton.Click += delegate { OnGDPRShowDialogs(); };

            // Set offerwall callback
            // It's good to set it on beggining of the appplication's logic
            Enhance.SetReceivedCurrencyCallback(OnCurrencyReceived);

            // Request permission (notifications)
            // This can be done at any point 
            Enhance.RequestLocalNotificationPermission(OnPermissionGranted, OnPermissionRejected);
        }

        // Interstitial Ad
        protected void OnShowInterstitialAd()
        {
            if (!Enhance.IsInterstitialReady())
            {
                writeLog("Interstitial ad is not ready");
                return;   
            }

            Enhance.ShowInterstitialAd();
            writeLog("Showing interstitial ad");
        }

        // Rewarded Ad
        protected void OnShowRewardedAd()
        {
            if (!Enhance.IsRewardedAdReady()) 
            {
                writeLog("Rewarded ad is not ready");
                return;
            }

            Enhance.ShowRewardedAd(OnRewardGranted, OnRewardDeclined, OnRewardUnavailable);
            writeLog("Showing rewarded ad");
        }

        protected void OnRewardGranted(Enhance.RewardType rewardType, int rewardValue)
        {
            // Reward granted (user watched the ad for example)
            // You can check reward type:

            if (rewardType == Enhance.RewardType.Item)
                writeLog("Reward granted (item)");
            else if (rewardType == Enhance.RewardType.Coins)
                writeLog("Reward granted (coins), value: " + rewardValue);
            else
                writeLog("Unknown reward granted");
        }

        protected void OnRewardDeclined()
        {
            // Reward declined (user closed the ad for example)
            writeLog("Reward declined");
        }

        protected void OnRewardUnavailable()
        {
            // Reward unavailable (network error for example)
            writeLog("Reward unavailable");
        }

        // Banner ad
        protected void OnToggleBanner()
        {
            // Hide banner if visible
            if(isBannerAdShown)
            {
                isBannerAdShown = false;
                Enhance.HideBannerAd();
                writeLog("Hiding banner ad");
                return;
            }

            if(!Enhance.IsBannerAdReady())
            {
                writeLog("Banner ad is not ready");
                return;
            }

            isBannerAdShown = true;
            Enhance.ShowBannerAdWithPosition(Enhance.Position.Top);
            writeLog("Showing banner ad");
			// You can also use:
			// Enhance.ShowBannerAdWithPosition(Enhance.Position.Bottom);
		}

        // Offerwall

        protected void OnShowOfferwall()
        {
            if (!Enhance.IsOfferwallReady())
            {
                writeLog("Offerwall is not ready");
                return;
            }

            Enhance.ShowOfferwall();
            writeLog("Showing offerwall");
        }

        protected void OnCurrencyReceived(int amount)
        {
            // User received a reward from offerwall network
            writeLog("Currency received: " + amount);
        }

        // Special Offer

        protected void OnShowSpecialOffer()
        {
            if(!Enhance.IsSpecialOfferReady())
            {
                writeLog("Special offer is not ready");
                return;
            }

            Enhance.ShowSpecialOffer();
            writeLog("Showing special offer");
        }

        // Analytics

        protected void OnLogEvent()
        {
            // Simple event
            Enhance.LogEvent("event_type");
            // Event with an additional parameter
            Enhance.LogEvent("event_type", "event_param_key", "event_param_value");

            writeLog("Sent analytics event");
        }

        // Local Notifications

        protected void OnEnableLocalNotification()
        {
            // You can't enable local notifications without permission

            if(!hasLocalNotificationPermission)
            {
                writeLog("Permission is not granted");
                return;
            }

            Enhance.EnableLocalNotification("Enhance", "Local Notification!", 5);
            writeLog("Enabled local notification");
        }

        protected void OnDisableLocalNotification()
        {
            if(!hasLocalNotificationPermission)
            {
                writeLog("Permission is not granted");
                return;
            }

            Enhance.DisableLocalNotification();
            writeLog("Disabled local notification");
        }

        protected void OnPermissionGranted()
        {
            hasLocalNotificationPermission = true;
        }

        protected void OnPermissionRejected()
        {
            hasLocalNotificationPermission = false;
        }

        // In-App Purchases

        protected void OnAttemptPurchase()
        {
            Enhance.Purchases.AttemptPurchase(productName, OnPurchaseSuccess, OnPurchaseFailed);
            writeLog("Attempting purchase");
        }

        protected void OnPurchaseSuccess()
        {
            updateIAPLabel();
            writeLog("Purchase success");
        }

        protected void OnPurchaseFailed()
        {
            writeLog("Purchase failed");
        }

        protected void OnAttemptConsume()
        {
            Enhance.Purchases.Consume(productName, OnConsumeSuccess, OnConsumeFailed);
            writeLog("Attempting consume");
        }

        protected void OnConsumeSuccess()
        {
			updateIAPLabel();
			writeLog("Consume success");
        }

        protected void OnConsumeFailed()
        {
            writeLog("Consume failed");
        }

        protected void updateIAPLabel() 
        {
            string title = Enhance.Purchases.GetDisplayTitle(productName, "Default Title");
            string price = Enhance.Purchases.GetDisplayPrice(productName, "Default Price");
            int quantity = Enhance.Purchases.GetOwnedItemCount(productName);

            TextView label = FindViewById<TextView>(Resource.Id.labelView);
            label.Text = title + " - " + price + " - Qty: " + quantity;
        }

        // GDPR

        protected void OnGDPROptIn()
        {
            Enhance.ServiceTermsOptIn();
            writeLog("Called explicit opt-in");
        }

        protected void OnGDPROptOut()
        {
            Enhance.ServiceTermsOptOut();
            writeLog("Called explicit opt-out");
        }

        protected void OnGDPRShowDialogs()
        {
            Enhance.RequiresDataConsentOptIn(OnServiceOptInRequirement);
        }

        protected void OnServiceOptInRequirement(bool isOptInRequired)
        {
            if(isOptInRequired)
            {
                Enhance.ShowServiceOptInDialogs(OnDialogsComplete);
            }
        }

        protected void OnDialogsComplete()
        {
            writeLog("Finished displaying opt-in dialogs");
        }

        // Write logs to screen(not related to Enhance)
        protected void writeLog(string text)
        {
            TextView logsView = FindViewById<TextView>(Resource.Id.logsView);
            logsView.Text = text;
        }
    }
}

