﻿using System;

using UIKit;

namespace Demo
{
    public partial class ViewController : UIViewController
    {
        protected bool isBannerShown = false;
        protected bool hasLocalNotificationPermission = false;
        protected string productName = "Enhance_SKU_One";

        protected ViewController(IntPtr handle) : base(handle)
        {
            // Note: this .ctor should not contain any initialization logic.
        }

        public override void ViewDidLoad()
        {
            base.ViewDidLoad();
            // Perform any additional setup after loading the view, typically from a nib.

            // Assign callbacks to buttons
            interstitial_button.TouchUpInside += delegate { OnShowInterstitialAd(); };
            rewarded_ad_button.TouchUpInside += delegate { OnShowRewardedAd(); };
            banner_button.TouchUpInside += delegate { OnToggleBanner(); };
            offerwall_button.TouchUpInside += delegate { OnShowOfferwall(); };
            special_offer_button.TouchUpInside += delegate { OnShowSpecialOffer(); };
            event_button.TouchUpInside += delegate { OnLogAnalyticsEvent(); };
            enable_notification_button.TouchUpInside += delegate { OnEnableLocalNotification(); };
            disable_notification_button.TouchUpInside += delegate { OnDisableLocalNotification(); };
            purchase_button.TouchUpInside += delegate { OnAttemptPurchase(); };
            consume_button.TouchUpInside += delegate { OnAttemptConsume(); };
            gdpr_opt_in_button.TouchUpInside += delegate { OnGDPROptIn(); };
            gdpr_opt_out_button.TouchUpInside += delegate { OnGDPROptOut(); };
            gdpr_dialogs_button.TouchUpInside += delegate { OnGDPRShowDialogs(); };

            // Set offerwall callback
            // It's important to do it in the beginning of the application's logic
            Enhance.SetReceivedCurrencyCallback(OnCurrencyGranted);

            // Request permission to schedule local notifications
            // This can be done at any point
            Enhance.RequestLocalNotificationPermission(OnPermissionGranted, OnPermissionRejected);
        }

        public override void DidReceiveMemoryWarning()
        {
            base.DidReceiveMemoryWarning();
            // Release any cached data, images, etc that aren't in use.
        }

        // Interstitial Ad

        protected void OnShowInterstitialAd()
        {
            if(!Enhance.IsInterstitialReady())
            {
                writeLog("Interstitial ad is not ready");
                return;
            }

            Enhance.ShowInterstitialAd();
            writeLog("Showing interstitial ad");
        }

        // Rewarded Ad

        protected void OnShowRewardedAd()
        {
            if(!Enhance.IsRewardedAdReady())
            {
                writeLog("Rewarded ad is not ready");
                return;
            }

            Enhance.ShowRewardedAd(OnRewardGranted, OnRewardDeclined, OnRewardUnavailable);
            writeLog("Showing rewarded ad");
        }

        protected void OnRewardGranted(Enhance.RewardType rewardType, int rewardValue)
        {
            // Reward granted (user watched the ad for example)
            // You can check reward type:

            if (rewardType == Enhance.RewardType.Item)
                writeLog("Reward granted (item)");
            else if (rewardType == Enhance.RewardType.Coins)
                writeLog("Reward granted (coins), value: " + rewardValue);
            else
                writeLog("Unknown reward granted");
        }

        protected void OnRewardDeclined()
        {
            // Reward declined (user closed the ad for example)
            writeLog("Reward declined");
        }

        protected void OnRewardUnavailable()
        {
            // Reward unavailable (network error for example)
            writeLog("Reward unavailable");
        }

        // Banner

        protected void OnToggleBanner()
        {
            // Hide if shown
            if(isBannerShown)
            {
                isBannerShown = false;
                Enhance.HideBannerAd();
                writeLog("Hiding banner ad");
                return;
            }

            if(!Enhance.IsBannerAdReady())
            {
                writeLog("Banner ad is not ready");
                return;
            }

            isBannerShown = true;
            Enhance.ShowBannerAdWithPosition(Enhance.Position.Top);
            writeLog("Showing banner ad");
            // You can also use:
            // Enhance.ShowBannerAdWithPosition(Enhance.Position.Bottom);
        }

        // Offerwall

        protected void OnShowOfferwall()
        {
            if (!Enhance.IsOfferwallReady())
            {
                writeLog("Offerwall is not ready");
                return;
            }

            Enhance.ShowOfferwall();
            writeLog("Showing offerwall");
        }

        protected void OnCurrencyGranted(int amount)
        {
            // User received a reward from offerwall network
            writeLog("Currency granted: " + amount);
        }

        // Special Offer

        protected void OnShowSpecialOffer()
        {
            if(!Enhance.IsSpecialOfferReady())
            {
                writeLog("Special offer is not ready");
                return;
            }

            Enhance.ShowSpecialOffer();
            writeLog("Showing special offer");
        }

        // Analytics

        protected void OnLogAnalyticsEvent()
        {
            // Simple event:
            Enhance.LogEvent("event_type");
            // Event with an additional parameter:
            Enhance.LogEvent("event_type", "event_param_key", "event_param_value");

            writeLog("Sent analytics event");
        }

        // Local Notification

        protected void OnEnableLocalNotification()
        {
            // You can't enable local notifications without permission

            if(!hasLocalNotificationPermission)
            {
                writeLog("Permission is not granted");
                return;
            }

            Enhance.EnableLocalNotification("Enhance", "Local Notification!", 5);
            writeLog("Enabled local notification");
        }

        protected void OnDisableLocalNotification()
        {
			if (!hasLocalNotificationPermission)
			{
				writeLog("Permission is not granted");
				return;
			}

            Enhance.DisableLocalNotification();
            writeLog("Disabled local notification");
        }

        protected void OnPermissionGranted()
        {
            hasLocalNotificationPermission = true;
        }

        protected void OnPermissionRejected()
        {
            hasLocalNotificationPermission = false;
        }

        protected void OnAttemptPurchase()
        {
            Enhance.Purchases.AttemptPurchase(productName, OnPurchaseSuccess, OnPurchaseFailed);
        }

        protected void OnPurchaseSuccess()
        {
            writeLog("Purchase success");
            updateIAPLabel();
        }

        protected void OnPurchaseFailed()
        {
            writeLog("Purchase failed");
        }

        protected void OnAttemptConsume()
        {
            Enhance.Purchases.Consume(productName, OnConsumeSuccess, OnConsumeFailed);
        }

        protected void OnConsumeSuccess()
        {
            writeLog("Consume success");
            updateIAPLabel();
        }

        protected void OnConsumeFailed()
        {
            writeLog("Consume failed");
        }

        protected void updateIAPLabel()
        {
            string title = Enhance.Purchases.GetDisplayTitle(productName, "Default Title");
            string price = Enhance.Purchases.GetDisplayPrice(productName, "Default Price");
            int quantity = Enhance.Purchases.GetOwnedItemCount(productName);

            label.Text = title + " - " + price + " - Qty: " + quantity;
        }

        protected void OnGDPROptIn()
        {
            Enhance.ServiceTermsOptIn();
            writeLog("Called explicit opt-in");
        }

        protected void OnGDPROptOut()
        {
            Enhance.ServiceTermsOptOut();
            writeLog("Called explicit opt-out");
        }

        protected void OnGDPRShowDialogs()
        {
            Enhance.RequiresDataConsentOptIn(OnOptInRequirement);
        }

        protected void OnOptInRequirement(bool isOptInRequired)
        {
            if(isOptInRequired)
            {
                Enhance.ShowServiceOptInDialogs(OnDialogsComplete);
            }
        }

        protected void OnDialogsComplete()
        {
            writeLog("Finished displaying opt-in dialogs");
        }

        // Write logs to screen (not Enhance related)
        protected void writeLog(string text)
        {
            string hour = DateTime.Now.Hour.ToString();
            if (hour.Length == 1) hour = "0" + hour;
            string minute = DateTime.Now.Minute.ToString();
            if (minute.Length == 1) minute = "0" + minute;
            string second = DateTime.Now.Second.ToString();
            if (second.Length == 1) second = "0" + second;

            log_field.Text = hour + ":" + minute + ":" + second + ": ";
            log_field.Text += text;

            System.Diagnostics.Debug.WriteLine(log_field.Text);
        }
    }
}
